@@ -19,6 +19,7 @@ class JijModelSamplerInterface(metaclass=ABCMeta):
                      search: bool = None,
                      max_iter=5,
                      alpha=1.0,
+                     timeout=None, 
                      **kwargs) -> dimod.SampleSet:
         """Sampling from PyQUBO model
 
@@ -32,7 +33,7 @@ class JijModelSamplerInterface(metaclass=ABCMeta):
             search (bool): Parameter search flag. Defaluts None.
             max_iter (int): maximum iteration of parameter search. Defaults to 5.
             alpha (float): for parameter search. Defaults to 1.0.
-
+            timeout (float): number of timeout for post request. Defaults to None.
 
         Returns:
             dimod.SampleSet: result.
@@ -48,11 +49,11 @@ class JijModelSamplerInterface(metaclass=ABCMeta):
         # ---------------------------------- validation
 
         # validation each setting --------------------
-        if feed_dict is not None:
-            for k in feed_dict.keys():
-                if k not in multipliers:
-                    raise ValueError(
-                        '{} is not defined in "multipliers".'.format(k))
+        # if feed_dict is not None:
+        #     for k in feed_dict.keys():
+        #         if k not in multipliers:
+        #             raise ValueError(
+        #                 '{} is not defined in "multipliers".'.format(k))
 
         for consts in multipliers.values():
             if isinstance(consts, list):
@@ -64,7 +65,7 @@ class JijModelSamplerInterface(metaclass=ABCMeta):
             elif isinstance(consts, str):
                 if consts not in conditions:
                     raise ValueError(
-                        '{} is not defined in "conditions".'.format(c)
+                        '{} is not defined in "conditions".'.format(consts)
                     )
             else:
                 raise TypeError(
@@ -97,12 +98,16 @@ class JijModelSamplerInterface(metaclass=ABCMeta):
             'algorithm': self.algorithm,
             'num_variables': len(model.compiled_qubo.variables),
             'problem': problem,
-            'problem_type': 'PyQUBO-Model',
+            'problem_type': 'PyQUBO-Model', 
             'parameters': parameters,
             'info': {}
         }
 
-        status_code, response = post_to_solver(self.url, self.token, body)
+        # if timeout is defined in script, use this value
+        if timeout:
+            self.timeout = timeout
+
+        status_code, response = post_to_solver(self.url, self.token, body, self.timeout)
         res = response['response']
         additional_info = response['info']
         res = response['response']
@@ -135,11 +140,13 @@ def _pyqubo_to_dict(model):
                 serierized_value.append([v, k.keys])
         dict_qubo[key] = serierized_value
 
+    # TODO: Validation check constraints
     constraints = {}
     for label, const in model.constraints.items():
         constraints[label] = []
         for key, v in const.polynomial.items():
             constraints[label].append([v] + list(key.keys))
+
     return {
         'qubo': dict_qubo,
         'constraints': constraints,
